" Set up leaders
let mapleader="\<SPACE>"
let maplocalleader=","

set shada="NONE"        " Prevent SHADA files from being generated or read
set laststatus=2        " Always show status bar
set updatetime=100      " Let plugins show effects after 100ms
set mouse-=a            " Disable mouse click to go to position
set encoding=utf-8
set exrc                " Allow loading local .nvimrc files
set secure              " Disallow use of autocmd, shell and write in local rc
set showcmd             " Show (partial) command in status line.
set showmatch           " Show matching brackets.
set ruler               " Show the line and column numbers of the cursor.
set formatoptions+=o    " Continue comment marker in new lines.
set formatoptions+=j    " Delete comment character when joining commented lines
set textwidth=78        " Hard-wrap long lines as you type them.
set autoindent          " Copy indent from current line when starting a new line
set noerrorbells        " No beeps.
set modeline            " Enable modeline.
set linespace=0         " Set line-spacing to minimum.
set nojoinspaces        " Prevents inserting two spaces after punctuation on a join (J)
set noshowmode          " Because of neovim's cursor shape
set splitbelow          " Horizontal split below current.
set splitright          " Vertical split to right of current.
set nobackup            " no backup files
set nowritebackup       " only in case you don't want a backup file while editing
set noswapfile          " no swap files
set nofoldenable        " Open folds by default
set undofile            " Enable undo persistence across sessions
set hidden
set noautochdir
set hlsearch
set nostartofline           " Do not jump to first character with page commands.
set ignorecase              " Make searching case insensitive
set smartcase               " ... unless the query has capital letters.
set magic                   " Use 'magic' patterns (extended regular expressions).
set autoread                " Autoload file if it changes on disk
set termguicolors           " Enable colors for terminal
set completeopt-=menu
set completeopt-=longest    " Don't insert the longest common text
set completeopt-=preview    " Hide the documentation preview window
set completeopt+=menuone    " Show the completions UI even with only 1 item
set completeopt+=noinsert   " Don't insert text automatically
set completeopt+=noselect   " Do not select a match in the menu
" Required for vim-workspace
" See https://github.com/thaerkh/vim-workspace/issues/11
set sessionoptions-=blank
set fileformat=unix
set inccommand=split
set switchbuf=useopen
set backspace=indent,eol,start
set scrolloff=3            " Show next 3 lines while scrolling.
set sidescrolloff=5        " Show next 5 columns while side-scrolling.
set diffopt=filler,internal,algorithm:histogram,indent-heuristic

" Wild menu
set wildmenu
set wildmode=longest:full,full
set wildoptions=pum
set pumblend=30
set wildignore=*.o,*.obj,*~,*.exe,*.a,*.pdb,*.lib
set wildignore+=__pycache__,.stversions,*.spl,*.out,%*
set wildignore+=*.so,*.dll,*.swp,*.egg,*.jar,*.class,*.pyc,*.pyo,*.bin,*.dex
set wildignore+=*.zip,*.7z,*.rar,*.gz,*.tar,*.gzip,*.bz2,*.tgz,*.xz
set wildignore+=*DS_Store*,*.ipch
set wildignore+=*.gem
set wildignore+=*.png,*.jpg,*.gif,*.bmp,*.tga,*.pcx,*.ppm,*.img,*.iso
set wildignore+=*.so,*.swp,*.zip,*/.Trash/**,*.pdf,*.dmg,*/.rbenv/**
set wildignore+=*/.nx/**,*.app,*.git,.git
set wildignore+=*.wav,*.mp3,*.ogg,*.pcm
set wildignore+=*.mht,*.suo,*.sdf,*.jnlp
set wildignore+=*.chm,*.epub,*.pdf,*.mobi,*.ttf
set wildignore+=*.mp4,*.avi,*.flv,*.mov,*.mkv,*.swf,*.swc
set wildignore+=*.ppt,*.pptx,*.docx,*.xlt,*.xls,*.xlsx,*.odt,*.wps
set wildignore+=*.msi,*.crx,*.deb,*.vfd,*.apk,*.ipa,*.bin,*.msu
set wildignore+=*.gba,*.sfc,*.078,*.nds,*.smd,*.smc
set wildignore+=*.linux2,*.win32,*.darwin,*.freebsd,*.linux,*.android

" We do this to prevent the loading of the system fzf.vim plugin. This is
" present at least on Arch/Manjaro
set rtp-=/usr/share/vim/vimfiles

" Disable providers we do not give a shit about
let g:loaded_python3_provider = 0
let g:loaded_python_provider = 0
let g:loaded_ruby_provider = 0
let g:loaded_perl_provider = 0
let g:loaded_node_provider = 0

" Disable some in built plugins completely
let g:loaded_netrw            = 1
let g:loaded_netrwPlugin      = 1
let g:loaded_matchparen       = 1
let g:loaded_matchit          = 1
let g:loaded_2html_plugin     = 1
let g:loaded_getscriptPlugin  = 1
let g:loaded_gzip             = 1
let g:loaded_logipat          = 1
let g:loaded_rrhelper         = 1
let g:loaded_spellfile_plugin = 1
let g:loaded_tarPlugin        = 1
let g:loaded_vimballPlugin    = 1
let g:loaded_zipPlugin        = 1

" Add the in built Cfilter plugin. Replaces QFGrep.
packadd cfilter

" Colorscheme
colorscheme yolokai
